
%define selinux_variants mls strict targeted
%define selinux_policyver %(sed -e 's,.*selinux-policy-\\([^/]*\\)/.*,\\1,' /usr/share/selinux/devel/policyhelp 2> /dev/null)
%define POLICYCOREUTILSVER 1.33.12-1

%define moduletype apps
%define modulename spacewalk-proxy

Name:           spacewalk-proxy-selinux
Version:        0.5.2
Release:        7%{?dist}
Summary:        SELinux policy module supporting Spacewalk Proxy

Group:          System Environment/Base
License:        GPLv2+
# This src.rpm is cannonical upstream. You can obtain it using
#      git clone git://git.fedorahosted.org/git/spacewalk.git/
# cd spacewalk
# make srpm TAG=%{name}-%{version}-%{release}
URL:            http://fedorahosted.org/spacewalk
Source0:        https://fedorahosted.org/releases/s/p/spacewalk/%{name}-%{version}.tar.gz
Patch0: spacewalk-proxy-selinux-0.5.2-1-to-spacewalk-proxy-selinux-0.5.2-7-sat.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  checkpolicy, selinux-policy-devel, hardlink
BuildRequires:  policycoreutils >= %{POLICYCOREUTILSVER}
BuildArch:      noarch

%if "%{selinux_policyver}" != ""
Requires:       selinux-policy >= %{selinux_policyver}
%endif
%if 0%{?rhel} == 5
Requires:        selinux-policy >= 2.4.6-80
%endif
Requires(post):   /usr/sbin/semodule, /sbin/restorecon, /usr/sbin/setsebool, /usr/sbin/selinuxenabled
Requires(postun): /usr/sbin/semodule, /sbin/restorecon
Requires:       spacewalk-proxy-management
Requires:       spacewalk-proxy-common
Requires:       spacewalk-proxy-broker

%description
SELinux policy module supporting Spacewalk Proxy.

%prep
%setup -q
%patch0 -p1

%build
# Build SELinux policy modules
perl -i -pe 'BEGIN { $VER = join ".", grep /^\d+$/, split /\./, "%{version}.%{release}"; } s!\@\@VERSION\@\@!$VER!g;' %{modulename}.te
for selinuxvariant in %{selinux_variants}
do
    make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile
    mv %{modulename}.pp %{modulename}.pp.${selinuxvariant}
    make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile clean
done

%install
rm -rf %{buildroot}

# Install SELinux policy modules
for selinuxvariant in %{selinux_variants}
  do
    install -d %{buildroot}%{_datadir}/selinux/${selinuxvariant}
    install -p -m 644 %{modulename}.pp.${selinuxvariant} \
           %{buildroot}%{_datadir}/selinux/${selinuxvariant}/%{modulename}.pp
  done

# Install SELinux interfaces
install -d %{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}
install -p -m 644 %{modulename}.if \
  %{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}/%{modulename}.if

# Hardlink identical policy module packages together
/usr/sbin/hardlink -cv %{buildroot}%{_datadir}/selinux

# Install spacewalk-proxy-selinux-enable which will be called in %posttrans
install -d %{buildroot}%{_sbindir}
install -p -m 755 %{name}-enable %{buildroot}%{_sbindir}/%{name}-enable

%clean
rm -rf %{buildroot}

%post
if /usr/sbin/selinuxenabled ; then
   %{_sbindir}/%{name}-enable
fi

%posttrans
if /usr/sbin/selinuxenabled ; then
  /sbin/restorecon -rvvi /var/log/rhn /var/cache/rhn/proxy-auth /var/spool/rhn-proxy
fi

%postun
# Clean up after package removal
if [ $1 -eq 0 ]; then
  for selinuxvariant in %{selinux_variants}
    do
      /usr/sbin/semodule -s ${selinuxvariant} -l > /dev/null 2>&1 \
        && /usr/sbin/semodule -s ${selinuxvariant} -r %{modulename} || :
    done
fi

/sbin/restorecon -rvvi /var/log/rhn /var/cache/rhn/proxy-auth /var/spool/rhn-proxy

%files
%defattr(-,root,root,0755)
%doc %{modulename}.fc %{modulename}.if %{modulename}.te
%{_datadir}/selinux/*/%{modulename}.pp
%{_datadir}/selinux/devel/include/%{moduletype}/%{modulename}.if
%attr(0755,root,root) %{_sbindir}/%{name}-enable

%changelog
* Thu Jul 02 2009 Brad Buckingham <bbuckingham@redhat.com> 0.5.2-7
- 509369 - run restorecon for /var/www/html/pub since its content is not owned
  by any package (msuchy@redhat.com)

* Thu Jun 18 2009 Brad Buckingham <bbuckingham@redhat.com> 0.5.2-6
- 505606 - Require at least selinux-policy 2.4.6-80 on RHEL 5.0.
  (jpazdziora@redhat.com)

* Mon Jun 15 2009 Brad Buckingham <bbuckingham@redhat.com> 0.5.2-5
- 498611 - run "semodule -i" in %post and restorecon in %posttrans
  (msuchy@redhat.com)

* Thu Jun 11 2009 Brad Buckingham <bbuckingham@redhat.com> 0.5.2-4
- 498611 - run restorecon in %posttrans (msuchy@redhat.com)

* Tue May 19 2009 Brad Buckingham <bbuckingham@redhat.com> 0.5.2-3
- Package rebuild

* Thu May 14 2009 Brad Buckingham <bbuckingham@redhat.com> 0.5.2-2
- Merge 'spacewalk/VADER' into sat53 (dgoodwin@redhat.com)
* Mon Apr 27 2009 Jan Pazdziora 0.5.2-1
- move the %post SELinux activation to /usr/sbin/spacewalk-proxy-selinux-enable
- use src.rpm packaging with single Source0

* Tue Apr 07 2009 jesus m. rodriguez <jesusr@redhat.com> 0.5.1-2
- Make spacewalk-proxy-selinux buildable with tito. (dgoodwin@redhat.com)

* Tue Jan 20 2009 Jan Pazdziora 0.5.1-1
- the initial release, based on spacewalk-selinux
